@@ -140,7 +140,7 @@ TuningInstanceAsyncMultiCrit = R6Class("TuningInstanceAsyncMultiCrit",
 
       # set the column with the learner param_vals that were not optimized over but set implicitly
       if (is.null(private$.result_learner_param_vals)) {
-        private$.result_learner_param_vals = self$objective$learner$param_set$values
+        private$.result_learner_param_vals = self$objective$default_values
         if (length(private$.result_learner_param_vals) == 0) private$.result_learner_param_vals = list()
         private$.result_learner_param_vals = replicate(nrow(private$.result_ydt), list(private$.result_learner_param_vals))
       }
@@ -186,3 +186,46 @@ TuningInstanceAsyncMultiCrit = R6Class("TuningInstanceAsyncMultiCrit",
     }
   )
 )
+
+#' @export
+tiny_logging.TuningInstanceAsyncMultiCrit = function(instance, optimizer) {
+  new_results = instance$rush$fetch_new_tasks()
+
+  if (nrow(new_results)) {
+    task_keys = instance$rush$tasks
+    ids = which(task_keys %in% new_results$keys)
+    best = instance$archive$best()
+    best_ids = which(task_keys %in% best$keys)
+
+    cns = intersect(c(instance$archive$cols_y, instance$archive$cols_x, "runtime_learners", "warnings", "errors"), colnames(new_results))
+
+    # unnest internal_tuned_values
+    if ("internal_tuned_values" %in% colnames(new_results)) {
+      cns = c(cns, names(new_results$internal_tuned_values[[1]]))
+      new_results = unnest(new_results, "internal_tuned_values")
+    }
+
+    for (i in seq_row(new_results)) {
+      lg$info("Evaluation %i: %s (Current best %s: %s)",
+        ids[i],
+        as_short_string(keep(as.list(new_results[i, cns, with = FALSE]), function(x) !is.na(x))),
+        as_short_string(best_ids),
+        paste0(map_chr(seq_row(best), function(i) as_short_string(keep(as.list(best[i, instance$archive$cols_y, with = FALSE]), function(x) !is.na(x)))), collapse = " & ")
+      )
+    }
+  }
+}
+
+#' @export
+tiny_result.TuningInstanceAsyncMultiCrit = function(instance, optimizer) {
+  result = copy(instance$result)
+  cns = c(instance$archive$cols_y, instance$archive$cols_x)
+  if ("internal_tuned_values" %in% colnames(result)) {
+    cns = c(cns, names(result$internal_tuned_values[[1]]))
+    result = unnest(result, "internal_tuned_values")
+  }
+
+  for (i in seq_row(instance$result)) {
+    lg$info(as_short_string(keep(as.list(result[i, cns, with = FALSE]), function(x) !is.na(x))))
+  }
+}
